export declare const eachQuarterOfIntervalWithOptions: import("./types.js").FPFn2<
  import("../eachQuarterOfInterval.js").EachQuarterOfIntervalResult<
    import("../fp.js").Interval<
      import("../fp.js").DateArg<Date>,
      import("../fp.js").DateArg<Date>
    >,
    | import("../eachQuarterOfInterval.js").EachQuarterOfIntervalOptions<Date>
    | undefined
  >,
  | import("../eachQuarterOfInterval.js").EachQuarterOfIntervalOptions<Date>
  | undefined,
  import("../fp.js").Interval<
    import("../fp.js").DateArg<Date>,
    import("../fp.js").DateArg<Date>
  >
>;
