export declare const differenceInDaysWithOptions: import("./types.js").FPFn3<
  number,
  import("../differenceInDays.js").DifferenceInDaysOptions | undefined,
  string | number | Date,
  string | number | Date
>;
