export declare const previousDayWithOptions: import("./types.js").FPFn3<
  Date,
  import("../previousDay.js").PreviousDayOptions<Date> | undefined,
  import("../fp.js").Day,
  import("../fp.js").DateArg<Date>
>;
