export declare const eachWeekendOfMonthWithOptions: import("./types.js").FPFn2<
  Date[],
  | import("../eachWeekendOfMonth.js").EachWeekendOfMonthOptions<Date>
  | undefined,
  import("../fp.js").DateArg<Date>
>;
