export declare const intervalToDuration: import("./types.js").FPFn1<
  import("../fp.js").Duration,
  import("../fp.js").Interval<
    import("../fp.js").DateArg<Date>,
    import("../fp.js").DateArg<Date>
  >
>;
