"use strict";
exports.eachQuarterOfIntervalWithOptions = void 0;

var _index = require("../eachQuarterOfInterval.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const eachQuarterOfIntervalWithOptions =
  (exports.eachQuarterOfIntervalWithOptions = (0, _index2.convertToFP)(
    _index.eachQuarterOfInterval,
    2,
  ));
