export declare const setISOWeekYearWithOptions: import("./types.js").FPFn3<
  Date,
  | import("../setISOWeekYear.js").SetISOWeekYearOptions<Date>
  | undefined,
  number,
  import("../fp.js").DateArg<Date>
>;
