"use strict";
exports.differenceInMonthsWithOptions = void 0;

var _index = require("../differenceInMonths.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const differenceInMonthsWithOptions = (exports.differenceInMonthsWithOptions =
  (0, _index2.convertToFP)(_index.differenceInMonths, 3));
