export declare const intervalToDurationWithOptions: import("./types.js").FPFn2<
  import("../fp.js").Duration,
  | import("../intervalToDuration.js").IntervalToDurationOptions
  | undefined,
  import("../fp.js").Interval<
    import("../fp.js").DateArg<Date>,
    import("../fp.js").DateArg<Date>
  >
>;
