export declare const setMillisecondsWithOptions: import("./types.js").FPFn3<
  Date,
  | import("../setMilliseconds.js").SetMillisecondsOptions<Date>
  | undefined,
  number,
  import("../fp.js").DateArg<Date>
>;
