export declare const eachWeekendOfYearWithOptions: import("./types.js").FPFn2<
  Date[],
  | import("../eachWeekendOfYear.js").EachWeekendOfYearOptions<Date>
  | undefined,
  import("../fp.js").DateArg<Date>
>;
