export declare const isSameMonthWithOptions: import("./types.js").FPFn3<
  boolean,
  import("../isSameMonth.js").IsSameMonthOptions | undefined,
  string | number | Date,
  string | number | Date
>;
