"use strict";
exports.formatDistanceStrictWithOptions = void 0;

var _index = require("../formatDistanceStrict.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const formatDistanceStrictWithOptions =
  (exports.formatDistanceStrictWithOptions = (0, _index2.convertToFP)(
    _index.formatDistanceStrict,
    3,
  ));
