export declare const interval: import("./types.js").FPFn2<
  import("../interval.js").IntervalResult<
    import("../fp.js").DateArg<Date>,
    import("../fp.js").DateArg<Date>,
    import("../interval.js").IntervalOptions<Date> | undefined
  >,
  import("../fp.js").DateArg<Date>,
  import("../fp.js").DateArg<Date>
>;
